@@ -37,7 +37,7 @@ init_ashints (ASHints * hints)
 {
 	if (hints)
 	{										   /* some defaults to start with : */
-		hints->flags = AS_Gravity | AS_AcceptsFocus | AS_Titlebar | AS_Handles | AS_Border;
+		hints->flags = AS_Gravity | AS_AcceptsFocus | AS_Titlebar | AS_IconTitle | AS_Handles | AS_Border;
         /* can't gracefully close the window if it does not support WM_DELETE_WINDOW */
         hints->function_mask = ~(AS_FuncClose|AS_FuncPinMenu);
         hints->gravity = NorthWestGravity;
@@ -273,7 +273,7 @@ merge_hints (ASRawHints * raw, ASDatabase * db, ASStatusHints * status,
 	if ((clean = reusable_memory) == NULL)
 		clean = (ASHints *) safecalloc (1, sizeof (ASHints));
 	else
-		memset (reusable_memory, 0x00, sizeof (ASHints));
+		memset (clean, 0x00, sizeof (ASHints));
 	if (status)
 		memset (status, 0x00, sizeof (ASStatusHints));
 
@@ -969,6 +969,7 @@ static ASFlagType extwm_types_start_properties[][3] = {
 	{EXTWM_TypeNormal, AS_LayerNormal, 0},  
 	{EXTWM_TypeUtility, AS_LayerTop, 0}, 	
 	{EXTWM_TypeSplash, AS_LayerTop, AS_ShortLived },
+	{EXTWM_TypeASModule, AS_LayerNormal, AS_StartsSticky },
 	{0, 0, 0}
 };
 static ASFlagsXref extwm_type_xref[] = {	   /*Flag              Set if Set,      Clear if Set,     Set if Clear,    Clear if Clear  */
@@ -977,6 +978,7 @@ static ASFlagsXref extwm_type_xref[] = {	   /*Flag              Set if Set,
 	{EXTWM_TypeToolbar, 0, AS_Handles | AS_Frame , 0, 0},
 	{EXTWM_TypeMenu, AS_SkipWinList | AS_DontCirculate, AS_Handles | AS_Frame, 0, 0},
 	{EXTWM_TypeDialog, AS_ShortLived, 0 /*may need to remove handles */ , 0, 0},
+	{EXTWM_TypeASModule, AS_Module, 0, 0, AS_Module },
 	{0, 0, 0, 0, 0}
 };
 static ASFlagsXref extwm_type_func_mask[] = {  /*Flag             Set if Set,  Clear if Set,     Set if Clear  , Clear if Clear  */
@@ -1049,7 +1051,9 @@ merge_extwm_hints (ASHints * clean, ASRawHints * raw,
 			for (i = 0; extwm_types_start_properties[i][0] != 0; i++)
 				if (get_flags (eh->flags, extwm_types_start_properties[i][0]))
 				{
-					status->layer = extwm_types_start_properties[i][1];
+					if( !get_flags (status->flags, AS_StartLayer) ||
+						status->layer < extwm_types_start_properties[i][1] ) 
+						status->layer = extwm_types_start_properties[i][1];
 					set_flags (status->flags, AS_StartLayer);
 					set_flags (status->flags, extwm_types_start_properties[i][2]);
 				}
@@ -1130,6 +1134,7 @@ merge_asdb_hints (ASHints * clean, ASRawHints * raw, ASDatabaseRecord * db_rec,
 		{STYLE_HANDLES, AS_Handles, 0, 0, AS_Handles},
 		{STYLE_FOCUS_ON_MAP, AS_FocusOnMap, 0, 0, AS_FocusOnMap},
 		{STYLE_LONG_LIVING, 0, AS_ShortLived, AS_ShortLived, 0},
+		{STYLE_IGNORE_CONFIG, AS_IgnoreConfigRequest, 0, 0, AS_IgnoreConfigRequest},
 		{0, 0, 0, 0, 0}
 	};
 
@@ -1286,7 +1291,7 @@ update_property_hints (Window w, Atom property, ASHints * hints, ASStatusHints *
 		return False;
 	memset (&raw, 0x00, sizeof (ASRawHints));
 	raw.wm_state_icon_win = status->icon_window;
-	raw.scr = &Scr;
+	raw.scr = ASDefaultScr;
 	if (handle_client_property_update (w, property, &raw))
 	{
 		/* Here we are only interested in properties updtaed by the Window Manager : */
@@ -1337,7 +1342,7 @@ update_cmd_line_hints (Window w, Atom property,
 	ASRawHints    raw;
 
 	memset (&raw, 0x00, sizeof (ASRawHints));
-	raw.scr = &Scr;
+	raw.scr = ASDefaultScr;
 	show_debug (__FILE__, __FUNCTION__, __LINE__, "trying to handle property change for WM_COMMAND");
 	if (handle_manager_property_update (w, property, &raw))
 	{
@@ -1355,14 +1360,14 @@ update_property_hints_manager (Window w, Atom property, ASSupportedHints * list,
 	Bool          changed = False;
 
 	memset (&raw, 0x00, sizeof (ASRawHints));
-	raw.scr = &Scr;
+	raw.scr = ASDefaultScr;
 	if (status)
 		raw.wm_state_icon_win = status->icon_window;
 	show_debug (__FILE__, __FUNCTION__, __LINE__, "trying to handle property change");
 	if (handle_manager_property_update (w, property, &raw))
 	{
 		ASHints       clean;
-
+		memset( &clean, 0x00, sizeof(ASHints));
 		show_debug (__FILE__, __FUNCTION__, __LINE__, "property update handled");
 		if (property == _XA_WM_STATE)
 		{
@@ -1418,8 +1423,11 @@ update_property_hints_manager (Window w, Atom property, ASSupportedHints * list,
 				hints->icon_name_idx = clean.icon_name_idx;
 				show_debug (__FILE__, __FUNCTION__, __LINE__, "names set");
 
-				hints->flags = clean.flags ;
-				hints->function_mask = clean.function_mask ;
+				/* Must not do that as it requires sugnificant changes in decorations and stuff : 
+				 * and should be done only when FollowTitleChanges is requested */
+				/* hints->flags = clean.flags ;
+				   hints->function_mask = clean.function_mask ;
+				 */
 			} else if (property == XA_WM_HINTS)
 			{
 
@@ -1682,7 +1690,7 @@ translate_asgeometry (ScreenInfo * scr, ASGeometry * asg, int *px, int *py, unsi
 	unsigned int  width = 1, height = 1;
 
 	if (scr == NULL)
-		scr = &Scr;
+		scr = ASDefaultScr;
 
 	if (asg)
 	{
@@ -1864,9 +1872,14 @@ status2anchor (XRectangle * anchor, ASHints * hints, ASStatusHints * status, uns
 {
 	if (get_flags (status->flags, AS_Size))
 	{
+		int w, h ;
 		constrain_size (hints, status, vwidth, vheight);
-        anchor->width = status->width - (status->frame_size[FR_W]+status->frame_size[FR_E]);
-        anchor->height = status->height - (status->frame_size[FR_N]+status->frame_size[FR_S]);
+		w = (int)status->width - ((int)status->frame_size[FR_W]+(int)status->frame_size[FR_E]);
+		if( w > 0 )
+        	anchor->width = w ;
+		h = (int)status->height - ((int)status->frame_size[FR_N]+(int)status->frame_size[FR_S]);
+		if( h > 0 ) 
+        	anchor->height = h ;
 	}
 
 	if (get_flags (status->flags, AS_Position))
@@ -1892,8 +1905,8 @@ status2anchor (XRectangle * anchor, ASHints * hints, ASStatusHints * status, uns
 		LOCAL_DEBUG_OUT( "anchor = %+d%+d", anchor->x, anchor->y );
 		if (!get_flags (status->flags, AS_Sticky))
 		{
-			anchor->x += status->viewport_x;
-			anchor->y += status->viewport_y;
+			anchor->x += (int)status->viewport_x;
+			anchor->y += (int)status->viewport_y;
 		}
 		LOCAL_DEBUG_OUT( "anchor = %+d%+d", anchor->x, anchor->y );
 	}
@@ -1927,8 +1940,8 @@ anchor2status (ASStatusHints * status, ASHints * hints, XRectangle * anchor)
 	LOCAL_DEBUG_OUT( "status = %+d%+d", status->x, status->y );
 	if (!get_flags (status->flags, AS_Sticky))
 	{
-		status->x -= status->viewport_x;
-		status->y -= status->viewport_y;
+		status->x -= (int)status->viewport_x;
+		status->y -= (int)status->viewport_y;
 	}
 	LOCAL_DEBUG_OUT( "status = %+d%+d", status->x, status->y );
 	set_flags (status->flags, AS_Position);
@@ -2560,7 +2573,7 @@ print_status_hints (stream_func func, void *stream, ASStatusHints * status)
 	if (get_flags (status->flags, AS_Desktop))
 		func (stream, "STATUS.desktop = %d;\n", status->desktop);
 	if (get_flags (status->flags, AS_Layer))
-		func (stream, "STATUS.desktop = %d;\n", status->layer);
+		func (stream, "STATUS.layer = %d;\n", status->layer);
 	if (get_flags (status->flags, AS_StartViewportX | AS_StartViewportX))
 	{
 		func (stream, "STATUS.viewport_x = %d;\n", status->viewport_x);
